@@ -29,7 +29,8 @@ from sqlalchemy import create_engine, false, func, or_, text, true
 from sqlalchemy.engine.base import Connection
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import Session, relationship, sessionmaker
-from sqlalchemy.sql.expression import desc, distinct
+from sqlalchemy.sql.expression import asc, desc, distinct
+from sqlalchemy.sql.schema import UniqueConstraint
 from sqlalchemy.sql.sqltypes import Numeric
 
 from spellbot.constants import (
@@ -56,15 +57,20 @@ class Server(Base):
     prefix = Column(String(10), nullable=False, default="!")
     expire = Column(Integer, nullable=False, server_default=text("30"))  # minutes
     links = Column(String(10), nullable=False, server_default=text("'public'"))
+    show_spectate_link = Column(Boolean, nullable=False, server_default=false())
     motd = Column(String(10), nullable=False, server_default=text("'both'"))
     power_enabled = Column(Boolean, nullable=False, server_default=true())
     tags_enabled = Column(Boolean, nullable=False, server_default=true())
     create_voice = Column(Boolean, nullable=False, server_default=false())
     smotd = Column(String(255))
+    voice_category_prefix = Column(String(40))
     games = relationship("Game", back_populates="server", uselist=True)
     channels = relationship("Channel", back_populates="server", uselist=True)
+    auto_verify_channels = relationship(
+        "AutoVerifyChannel", back_populates="server", uselist=True
+    )
     channel_settings = relationship(
-        "ChannelSettings", back_populates="server", uselist=True
+        "ChannelSettings", back_populates="server", uselist=True, lazy="dynamic"
     )
     teams = relationship("Team", back_populates="server", uselist=True)
 
@@ -73,6 +79,10 @@ class Server(Base):
             channel.channel_xid == channel_xid for channel in self.channels
         )
 
+    def channel_settings_for(self, channel_xid: int) -> Optional[ChannelSettings]:
+        filters = {"channel_xid": channel_xid}
+        return self.channel_settings.filter_by(**filters).one_or_none()  # type: ignore
+
     @classmethod
     def recent_metrics(cls, session: Session) -> dict:
         data = [
@@ -131,6 +141,7 @@ class Server(Base):
                 "guild_xid": self.guild_xid,
                 "prefix": self.prefix,
                 "expire": self.expire,
+                "show_spectate_link": self.show_spectate_link,
                 "channels": [channel.channel_xid for channel in self.channels],
                 "teams": [team.name for team in self.teams],
             }
@@ -154,7 +165,7 @@ class Team(Base):
         rows = (
             session.query(Team.name, func.sum(UserPoints.points))
             .select_from(User)
-            .join(UserTeam)
+            .join(UserServerSettings)
             .join(UserPoints)
             .join(Team)
             .filter(Team.guild_xid == guild_xid)
@@ -181,6 +192,18 @@ class Channel(Base):
     server = relationship("Server", back_populates="channels")
 
 
+class AutoVerifyChannel(Base):
+    __tablename__ = "auto_verify_channels"
+    channel_xid = Column(BigInteger, primary_key=True, nullable=False)
+    guild_xid = Column(
+        BigInteger,
+        ForeignKey("servers.guild_xid", ondelete="CASCADE"),
+        nullable=False,
+        index=True,
+    )
+    server = relationship("Server", back_populates="auto_verify_channels")
+
+
 class ChannelSettings(Base):
     __tablename__ = "channel_settings"
     channel_xid = Column(BigInteger, primary_key=True, nullable=False)
@@ -190,7 +213,13 @@ class ChannelSettings(Base):
         nullable=False,
         index=True,
     )
+    cached_name = Column(String(50))
+    created_at = Column(DateTime, nullable=False, default=datetime.utcnow)
+    updated_at = Column(DateTime, nullable=False, default=datetime.utcnow)
     default_size = Column(Integer, nullable=True)
+    require_verification = Column(Boolean, nullable=False, server_default=false())
+    cmotd = Column(String(255))
+    verify_message = Column(String(255))
     server = relationship("Server", back_populates="channel_settings")
 
 
@@ -219,10 +248,34 @@ class Event(Base):
         return json.dumps({"id": self.id})
 
 
+users_blocks = Table(
+    "users_blocks",
+    Base.metadata,
+    Column(
+        "user_xid",
+        BigInteger,
+        ForeignKey("users.xid", ondelete="CASCADE"),
+        primary_key=True,
+        nullable=False,
+        index=True,
+    ),
+    Column(
+        "blocked_user_xid",
+        BigInteger,
+        ForeignKey("users.xid", ondelete="CASCADE"),
+        primary_key=True,
+        nullable=False,
+        index=True,
+    ),
+    UniqueConstraint("user_xid", "blocked_user_xid", name="uix_1"),
+)
+
+
 class User(Base):
     __tablename__ = "users"
     xid = Column(BigInteger, primary_key=True, nullable=False)
     created_at = Column(DateTime, nullable=False, default=datetime.utcnow)
+    updated_at = Column(DateTime, nullable=False, default=datetime.utcnow)
     game_id = Column(
         Integer, ForeignKey("games.id", ondelete="SET NULL"), nullable=True, index=True
     )
@@ -230,6 +283,31 @@ class User(Base):
     power = Column(Integer, nullable=True)
     game = relationship("Game", back_populates="users")
 
+    blocks = relationship(
+        "User",
+        secondary=users_blocks,
+        primaryjoin=xid == users_blocks.c.user_xid,
+        secondaryjoin=xid == users_blocks.c.blocked_user_xid,
+        backref="blocked_by",
+    )
+
+    def blocked(self, game: Game) -> bool:
+        session = Session.object_session(self)
+        other_user_xids = [u.xid for u in game.users]
+        query = session.query(users_blocks).filter(
+            or_(
+                and_(
+                    users_blocks.c.user_xid == self.xid,
+                    users_blocks.c.blocked_user_xid.in_(other_user_xids),
+                ),
+                and_(
+                    users_blocks.c.blocked_user_xid == self.xid,
+                    users_blocks.c.user_xid.in_(other_user_xids),
+                ),
+            )
+        )
+        return cast(bool, session.query(query.exists()).scalar())
+
     @classmethod
     def recent_metrics(cls, session: Session) -> dict:
         data = [
@@ -266,15 +344,16 @@ class User(Base):
 
     def to_json(self) -> dict:
         return {
-            "xid": self.xid,
-            "game_id": self.game_id,
             "cached_name": self.cached_name,
+            "created_at": str(self.created_at),
+            "game_id": self.game_id,
             "power": self.power,
+            "xid": self.xid,
         }
 
 
-class UserTeam(Base):
-    __tablename__ = "user_teams"
+class UserServerSettings(Base):
+    __tablename__ = "user_server_settings"
     user_xid = Column(
         BigInteger,
         ForeignKey("users.xid", ondelete="CASCADE"),
@@ -287,7 +366,8 @@ class UserTeam(Base):
         primary_key=True,
         nullable=False,
     )
-    team_id = Column(Integer, ForeignKey("teams.id", ondelete="CASCADE"), nullable=False)
+    team_id = Column(Integer, ForeignKey("teams.id", ondelete="CASCADE"), nullable=True)
+    verified = Column(Boolean, nullable=True, server_default=false())
 
 
 class UserPoints(Base):
@@ -479,7 +559,7 @@ class Game(Base):
             .filter(and_(Game.id.in_(inner), or_(*tag_filters)))
             .group_by(Game.id)
             .having(having_filters[0])
-            .order_by(desc(Game.updated_at))
+            .order_by(asc(Game.updated_at))
         )
         game: Optional[Game] = outer.first()
         return game
@@ -523,12 +603,12 @@ class Game(Base):
 
     @classmethod
     def average_wait_times(cls, session: Session):
-        if "sqlite" in session.bind.dialect.name:
+        if "sqlite" in session.bind.dialect.name:  # pragma: no cover
             avg = func.avg(
                 (func.julianday(Game.updated_at) - func.julianday(Game.created_at))
                 * 1440.0
             )
-        else:
+        else:  # pragma: no cover
             avg = (
                 sql_cast(
                     func.avg(
@@ -621,6 +701,11 @@ class Game(Base):
                         "Click the link below to join your SpellTable game."
                         f"\n<{self.url}>"
                     )
+                    if self.server.show_spectate_link:
+                        description += (
+                            "\nOr spectate on the game with the following link."
+                            f"\n<{self.url}?spectate>"
+                        )
                 else:
                     description += (
                         "Sorry but SpellBot was unable to create a SpellTable link"
@@ -639,8 +724,12 @@ class Game(Base):
             description += (
                 "Please exchange Arena contact information and head over there to play!"
             )
+        if self.channel_xid:
+            channel_settings = self.server.channel_settings_for(self.channel_xid)
+            if channel_settings and channel_settings.cmotd:
+                description += f"\n{channel_settings.cmotd}"
         if self.server.smotd and show_motd:
-            description += f"\n\n{self.server.smotd}"
+            description += f"\n{self.server.smotd}"
         embed.description = description
 
         if self.voice_channel_xid:
